Converting features data between formats
========================================

The following modules help with converting font features information to and
for different formats.

.. automodule:: fontFeatures.feaLib
	:members:

.. automodule:: fontFeatures.ttLib
	:members:

.. automodule:: fontFeatures.fontDameLib
	:members:
